%define user_group  ircd

%global _hardened_build 1

Name:       ircd-ratbox
Version:    2.2.9
Release:    3%{?dist}
Summary:    Ircd-ratbox is an advanced, stable and fast ircd

License:    GPLv2
Group:      System Environment/Daemons

Conflicts:  ircd-hybrid
BuildRequires:  openssl-devel, bison, flex, systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils

URL:        http://www.ratbox.org/
Source0:    http://www.ratbox.org/download/%{name}-%{version}.tar.bz2
Source1:    ircd.service
Source2:    ircd.sysconfig
Source3:    ircd.fedora.conf
Source4:    ircd.logrotate
Source5:    ircd.tmpfiles.d.conf
Patch0:     ircd-ratbox-2.2.9-format-security.patch

%description
ircd-ratbox is an advanced, stable, fast ircd. It is an evolution where
ircd-hybrid left off around version 7-rc1. It supports the TS3 and TS5
protocols, and is used on EFnet and other IRC networks.


%package mkpasswd
Summary:    Password hash generator for ircd-ratbox
Group:      Applications/File

%description mkpasswd
Ircd-mkpasswd is a password hash generator for ircd-ratbox.

%prep
%setup -q
%patch0 -p1 -b .format-security

%{__sed} -i \
    -e 's|#servlink_path = "/usr/local/ircd/bin/servlink";|servlink_path = "%{_bindir}/servlink";|' \
    -e 's|/usr/local/ircd/modules|%{_datadir}/ircd/modules|g' \
    -e 's|/usr/local/ircd/etc/|%{_sysconfdir}/ircd|g' \
    -e 's|"logs/|"%{_var}/log|g' \
    doc/example.*conf

sed 's/-Werror//g' -i configure

%configure \
    --bindir=%{_bindir} \
    --sbindir=%{_sbindir} \
    --with-helpdir=%{_datadir}/ircd \
    --with-moduledir=%{_datadir}/ircd/modules \
    --with-confdir=%{_sysconfdir}/ircd \
    --mandir=%{_mandir} \
    --with-logdir=%{_var}/log/ircd \
    --enable-ipv6 \
    --enable-openssl \
    --enable-zlib \
    --with-nicklen=32 \
    --with-topiclen=350 \
    --enable-small-net \
    --enable-services

%build
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT%{_sbindir} $RPM_BUILD_ROOT%{_datadir}/ircd $RPM_BUILD_ROOT%{_var}/log $RPM_BUILD_ROOT%{_sysconfdir}/ircd
make install DESTDIR=$RPM_BUILD_ROOT
install -D -m644 %{SOURCE1} $RPM_BUILD_ROOT/%{_unitdir}/ircd.service
install -D -m644 %{SOURCE2} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ircd
install -D -m644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/ircd/ircd.conf
install -D -m664 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/ircd
install -D -m644 %{SOURCE5} $RPM_BUILD_ROOT/%{_tmpfilesdir}/ircd.conf
mv $RPM_BUILD_ROOT%{_bindir}/mkpasswd $RPM_BUILD_ROOT%{_bindir}/ircd-mkpasswd
mv $RPM_BUILD_ROOT%{_datadir}/ircd-old/modules $RPM_BUILD_ROOT%{_datadir}/ircd/modules
rm -fr $RPM_BUILD_ROOT%{_datadir}/ircd-old
mkdir -p $RPM_BUILD_ROOT/run/ircd-ratbox

%clean
rm -rf $RPM_BUILD_ROOT


%pre
getent group ircd  >/dev/null || groupadd -r ircd
getent passwd ircd >/dev/null || \
useradd -r -g ircd -d /run/ircd-ratbox -s /sbin/nologin \
    -c "ircd-ratbox user" ircd

%post
%systemd_post ircd.service

%preun
%systemd_preun ircd.service

%postun
%systemd_postun_with_restart ircd.service


%triggerun -- ircd-ratbox < 2.2.8-9
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply ircd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save ircd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del ircd >/dev/null 2>&1 || :
/bin/systemctl try-restart ircd.service >/dev/null 2>&1 || :

%files
%doc ChangeLog CREDITS INSTALL LICENSE README RELNOTES SVN-Access doc/*
%{_bindir}/convertilines
%{_bindir}/convertklines
%{_bindir}/ircd
%{_bindir}/servlink
%{_bindir}/viconf
%{_bindir}/viklines
%{_bindir}/vimotd
%{_datadir}/ircd*
%dir %{_sysconfdir}/ircd
%config(noreplace) %{_sysconfdir}/ircd/*
%{_sysconfdir}/sysconfig/ircd
%{_unitdir}/ircd.service
%{_tmpfilesdir}/ircd.conf
%doc %{_mandir}/man8/ircd*
%dir %attr(750,ircd,ircd) %{_var}/log/ircd
%dir %attr(750,ircd,ircd) /run/ircd-ratbox
%config(noreplace) %{_sysconfdir}/logrotate.d/ircd

%files mkpasswd
%{_bindir}/ircd-mkpasswd

%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Feb 23 2014 Nils Philippsen <nils@redhat.com> - 2.2.9-1
- fix build with -Werror=format-security (#1037135)
- build hardened executables (#955164)

* Fri Feb 21 2014 Nils Philippsen <nils@redhat.com> - 2.2.9-1
- version 2.2.9
- remove obsolete offbyone patch
- use working upstream and source URLs
- tidy up inconsistent and trailing whitespace
- add tmpfile.d configuration and adapt systemd service file (#1030161)
- use systemd macros (#850170)
- don't list files twice, mark all configuration as %%config(noreplace)
- don't specify %%defattr and BuildRoot
- change ircd user home directory to /run/ircd-ratbox
- fix systemd requirements

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Feb 11 2013 Lubomir Rintel <lkundrak@v3.sk> - 2.2.8-11
- Own ircd homedir, SELinux would disallow creating it during installation

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Apr 18 2012 Jon Ciesla <limburgher@gmail.com> - 2.2.8-9
- Migrate to systemd, BZ 789704.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 2.2.8-6
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 2.2.8-3
- rebuild with new openssl

* Wed Aug 27 2008 Marek Mahut <mmahut@fedoraproject.org> - 2.2.8-2
- Initial package build
